@@ -1,4 +1,4 @@
-from dbs import dbs
+from dbs import getDBs, getDBsFromFile
 import os
 
 from postgres import postgres
@@ -10,7 +10,7 @@ connectors = {
 }
 
 required = ['params','db','q','name']
-optional = ['use_headers']
+optional = ['use_headers','dbconffile']
 
 
 class BaseQuery(object):
@@ -25,6 +25,12 @@ class BaseQuery(object):
 
   def __init__(self, **kwargs):
     self.connector = connectors['postgres']()
+    if 'dbconffile' in kwargs.keys():
+      dbs = getDBsFromFile(kwargs['dbconffile'])
+      self.conffile = kwargs['dbconffile']
+    else:
+      dbs = getDBs()
+
     if kwargs['db'] in dbs.keys():
       self.connector = connectors[dbs[kwargs['db']]['type']]()
 
