@@ -28,10 +28,10 @@ to start using the queries for that project
 Projects:"""
   print "\n".join(queries.keys())
 
-def setProject(proj):
+def setProject(proj,conffile):
   if proj in queries.keys():
     f = open(PROJFILE,"w")
-    f.write(json.dumps({'proj':proj}));
+    f.write(json.dumps({'proj':proj,'dbconf':conffile}));
     f.close()
     print "Project Set"
   else:
@@ -51,7 +51,9 @@ def pipeable():
   #is there a project file in the dir
   if PROJFILE in  os.listdir('.'):
     f = open(PROJFILE,'r')
-    proj = json.load(f)['proj']
+    conf = json.load(f)
+    proj = conf['proj']
+    dbconffile = conf['dbconf']
 
     #does the proj exist
     if proj not in queries.keys():
@@ -67,7 +69,11 @@ def pipeable():
 
   #if no project and single arg set the project
   if not proj and len(sys.argv) == 2:
-    setProject(sys.argv[1])
+    setProject(sys.argv[1],None)
+
+  #if no project and 1st sets project 2nd arg is location of dbconf.json
+  if not proj and len(sys.argv) == 3:
+    setProject(sys.argv[1],sys.argv[2])
 
 
   #if project and no arguments display the queries
@@ -104,7 +110,12 @@ def pipeable():
     class runStuff(BaseQuery):
       """anonymous runner"""
 
-    _run = runStuff(**queries[proj][querytorun].__dict__)
+    query_dict = queries[proj][querytorun].__dict__.copy()
+    if dbconffile:
+      query_dict['dbconffile'] = dbconffile
+
+    _run = runStuff(**query_dict)
+
     lines = _run.query(params)
     if len(lines) > 0:
       print "\n".join(lines)
