@@ -1,9 +1,15 @@
 import gdata.analytics.service
-from dbs import dbs
+from dbs import getDBs, getDBsFromFile
+import json
 class googleAnalytics(object):
 
 
   def conn(self):
+    if 'dbconffile' in dir(self):
+      dbs = getDBsFromFile(self.dbconffile)
+    else:
+      dbs = getDBs()
+
     analytics = gdata.analytics.service.AnalyticsDataService(email=dbs[self.db]['username'],password=dbs[self.db]['password'],source=dbs[self.db]['app'])
     analytics.ProgrammaticLogin()
     analytics.ssl = True
@@ -14,6 +20,7 @@ class googleAnalytics(object):
     conn = self.conn()
 
     query_dict = {}
+    self.q = json.loads(self.q)
     for i in range(len(self.params)):
       query_dict[self.params[i]] = params[i]
 
