@@ -1,10 +1,14 @@
-import pg
-from dbs import dbs
+from dbs import getDBs, getDBsFromFile
 
 class postgres(object):
 
 
   def getConn(self):
+    if 'dbconffile' in dir(self):
+      dbs = getDBsFromFile(self.dbconffile)
+    else:
+      dbs = getDBs()
+
     if self.db in dbs.keys():
       return pg.connect(dbs[self.db]['dbname'],dbs[self.db]['host'],dbs[self.db]['port'], None,None,dbs[self.db]['username'], dbs[self.db]['password'])
     else:
